//必要なメソッドをグローバルビルドから分割代入で取得
const { ref, onUpdated } = Vue;

import { useValidateRules } from '../../composables/use_validate_rules.js';
import { Modal } from '../../components/Modal.js';
import { useModal } from '../../composables/use_modal.js';

// コンポーネントを定義してエクスポート
export const UserEntry =
{
	props			:
	{
//		parent		: String
	},
	setup( props , context )
	{
		const form = ref( null );
		const form2 = ref( null );
		const name1 = ref( null );
		const name2 = ref( null );
		const mail = ref( null );
		const code = ref( null );
		const agree = ref( false );
		const terms	= ref( false );
		const entry_flag = ref( true );
		const code_flag = ref( false );
		const contract_content=ref(
`1.本ソフトウェアの全部又は一部を第三者に譲渡、貸与又は使用許諾する行為を禁止します。
2.本ソフトウェアの改変、リバースエンジニアリング、逆コンパイル，または逆アセンブルする行為を禁止します。
3.本ソフトウェアを第三者がコピーできるように公開する行為を禁止します。
4.本ソフトウェアをレンタル，リース，または貸与する行為を禁止します。
5.本ソフトウェアに表示されている著作権表示を削除し、又は変更する行為を禁止します。
6.本ソフトウェアの著作権は、製作者に帰属しています。本ソフトウェアは著作権法で保護されています。
7.本ソフトウェアの使用によりお客様または第三者が被った直接的、または間接的ないかなる損害についても製作者は一切責任を負わないものとします。
8.本ソフトウェアの機能の維持・強化、サポート（以下サービスといいます）は製作者が行いますが，製作者自身の健康状態の悪化や、やむを得ない事情でサービスを継続できないときは，製作者自身の判断でサービス終了30日前までにサポートページ、メールで告知致します。`
		);


		//バリデートオブジェクトを取得
		const rurles = useValidateRules();

		//モーダルオブジェクトを取得
		const modal = useModal();


		//ユーザーの仮登録処理
		const entryUser = async ()=>
		{
			const { valid } = await form.value.validate();

			//記入漏れであれば終了
			if(! valid )	return;

			await window.scroll({ top: 0, behavior: "auto", });

			modal.loading= true;

			//axiosのPOSTタイプではURLSearchParamsが必要
			const params = new URLSearchParams();
			params.append( 'action' , ACTION );
			params.append( 'domain' , DOMAIN );
			params.append( 'admin_mail' , ADMIN_MAIL );
			params.append( 'token' , TOKEN );
			params.append( 'name1' , name1.value );
			params.append( 'name2' , name2.value );
			params.append( 'mail' , mail.value );
			params.append( 'agree' , agree.value );
			params.append( 'terms' , terms.value );

			await axios.post( END_POINT , params )
			.then( res => 
			{
				modal.loading= false;

				console.log( res.data );

				//結果ダイアログを表示する
				modal.title	= res.data.title;
				modal.msg	= res.data.msg;
				modal.dialog= true;

				//仮会員登録に成功すれば
				if( res.data.status )
				{
					entry_flag.value	= false;
					code_flag.value		= true;
				}

			})
			.catch( error => 
			{
				modal.loading= false;

				alert( "エラーが発生しました。" );
				console.log( error );
			});

		};


		//4桁のコードの送信
		const sendCode = async ()=>
		{
			const { valid } = await form2.value.validate();

			//記入漏れであれば終了
			if(! valid )	return;

			await window.scroll({ top: 0, behavior: "auto", });

			modal.loading= true;

			//axiosのPOSTタイプではURLSearchParamsが必要
			const params = new URLSearchParams();
			params.append( 'action' , ACTION2 );
			params.append( 'domain' , DOMAIN );
			params.append( 'admin_mail' , ADMIN_MAIL );
			params.append( 'token' , TOKEN );
			params.append( 'name1' , name1.value );
			params.append( 'name2' , name2.value );
			params.append( 'mail' , mail.value );
			params.append( 'code' , code.value );

			await axios.post( END_POINT , params )
			.then( res => 
			{
				modal.loading= false;

				console.log( res.data );

				//結果ダイアログを表示する
				modal.title	= res.data.title;
				modal.msg	= res.data.msg;
				modal.dialog= true;

				if( res.data.status )
				{
					//ユーザーデータをAJAXで保存する
					saveUser();
				}

			})
			.catch( error => 
			{
				modal.loading= false;

				alert( "エラーが発生しました。" );
				console.log( error );
			});

		};



		//ユーザーデータをAJAXで保存する
		const saveUser = async ()=>
		{
			modal.loading= true;

			//axiosのPOSTタイプではURLSearchParamsが必要
			const params = new URLSearchParams();
			params.append( 'action' , ACTION3 );
			params.append( 'domain' , DOMAIN );
			params.append( 'admin_mail' , ADMIN_MAIL );
			params.append( 'token' , TOKEN );
			params.append( 'name1' , name1.value );
			params.append( 'name2' , name2.value );
			params.append( 'mail' , mail.value );


			await axios.post( END_POINT , params )
			.then( res => 
			{
				modal.loading= false;

				console.log( res.data );

				if( res.data.status )
				{
					modal.url= ADMIN_URL;
				}

				modal.dialog= true;

			})
			.catch( error => 
			{
				modal.loading= false;

				alert( "エラーが発生しました。" );
				console.log( error );
			});

		};



		return {
			entryUser ,
			sendCode ,
			form ,
			form2 ,
			name1 ,
			name2 ,
			mail ,
			code ,
			agree ,
			terms ,
			contract_content ,
			rurles ,
			modal ,
			entry_flag ,
			code_flag ,
		};
	},
	data			: () =>
	({

	}) ,
	methods			:
	{

	} ,
	components		:
	{
		'app-modal'	: Modal ,
	},
	template		: `

<!-- ユーザー登録 -->
<v-card v-if="entry_flag" class="mx-auto my-8 px-6 py-8" width="800" max-width="800">

	<v-form ref="form">

		<v-row>
			<v-col
			 cols="12"
			 sm="6"
			>

				<v-text-field
				 v-model="name1"
				 :rules="rurles.requireRules"
				 label="苗字"
				 variant="outlined"
				 required
				></v-text-field>

			</v-col>

			<v-col
			 cols="12"
			 sm="6"
			>

				<v-text-field
				 v-model="name2"
				 :rules="rurles.requireRules"
				 label="名前"
				 variant="outlined"
				 required
				></v-text-field>

			</v-col>
		</v-row>

		<v-text-field
		 v-model="mail"
		 :rules="rurles.mailRules"
		 label="メールアドレス"
		 variant="outlined"
		 required
		></v-text-field>

		<v-checkbox
		 v-model="agree"
		 color="red"
		 :rules="rurles.checkRules"
		 label="登録情報は正確です"
		 required
		></v-checkbox>

		<v-textarea
		 v-model="contract_content"
		 label="使用許諾"
		 auto-grow
		 variant="outlined"
		 rows="10"
		 shaped
		></v-textarea>

		<v-checkbox
		 v-model="terms"
		 color="red"
		 :rules="rurles.checkRules"
		 label="使用許諾に同意します"
		 required
		></v-checkbox>

		<v-alert
		 color="blue"
		 icon="mdi-alert-circle"
		 title="注意事項"
		 variant="outlined"
		>
		このユーザー登録情報は体験版と正規版において利用されます。変更はできませんので氏名は本名での登録をお勧めします。
		本名でない場合はメールアドレスが変わった際の本人確認が不可能なため、いかなる理由があっても変更はできかねますのでご了承下さい。
		</v-alert>


		<v-btn
		 color="success"
		 class="mt-4"
		 block
		 @click="entryUser"
		>
		登録する
		</v-btn>

	</v-form>
</v-card>
<!-- ユーザー登録 -->


<!-- コード入力 -->
<v-card v-if="code_flag" class="mx-auto my-8 px-6 py-8" width="600" max-width="600">

	<v-form ref="form2">

		<v-text-field
		 v-model="code"
		 :counter="4"
		 :rules="rurles.requireRules"
		 label="4桁のコード"
		 variant="outlined"
		 required
		></v-text-field>

		<v-btn
		 color="success"
		 class="mt-4"
		 block
		 @click="sendCode"
		>
		送信する
		</v-btn>

	</v-form>
</v-card>
<!-- /コード入力 -->

<!-- モーダル -->
<app-modal />
<!-- /モーダル -->

`
};
