<?php
/*
Plugin Name: member login mypage press
Plugin URI: https://wp-plugin.info/
Description: バージョンアップ用プロトタイプ。
Version: 0.0.2
Author: 阿修羅ワークス
Author URI: https://wp-plugin.info/
Last Update: 2018-05-01
Changelog: 初リリース
2018-05-01 ver0.0.2 クラス名をオンリーワンに変更
2017-11-09 ver0.0.1 初リリース
*/

//Joint Pressがあれば
if( class_exists( 'JointPress' ) )
{
	//インスタンスを生成する
	$PROTOTYPE_MemberLoginPress	= new ProtoType_MemberLoginPress();
}


//クラスを定義/////////////////////////////////////////////////////////////////
class ProtoType_MemberLoginPress
{

	//コンストラクタ 最初にやる処理をここに記述しておく////////////////////////
	function __construct()
	{
		//プラグインのファイル名だけを取得
		$item_name	= pathinfo( __FILE__ , PATHINFO_FILENAME );

		//管理メニューのアクションフック「admin_menu」で「ADMIN_MENU」関数を実行する
		add_action( 'admin_menu' , array( &$this , 'ADMIN_MENU' ) );

		//バージョンをチェックする
		add_action( 'init' , array( &$this , 'VERSION_CHECK_WRAPPER' ) );

		//アクションフックにAjaxを登録
		add_action( 'wp_ajax_' . $item_name . '-user_authentication', array( &$this , 'AJAX_AUTHENTICATION' ) );

		//ダッシュボードにメッセージを表示する
		add_action( 'admin_notices' , array( &$this , 'USER_DASHBOARD_NOTICE' ) );

	}
	//プロトタイプ版バージョンチェックラッパー/////////////////////////////////
	function VERSION_CHECK_WRAPPER() //ver1.2 2018.04.11
	{
		//管理画面でなければ終了
		if(! is_admin() ) { return; }

		global $JP;

		//プラグインのファイル名だけを取得
		$item_name = pathinfo( __FILE__ , PATHINFO_FILENAME );

		//保存されたオプション名
		$option_name	= $item_name . '-' . 'authentication';

		//オプション取得する
		$H_auth			= $JP->GET_OPTION( $option_name );

		//認証済みであれば
		if( $H_auth and is_array( $H_auth[ 'item' ] ) )
		{
			//現在のURL
			$ref_url		= ( empty( $_SERVER[ "HTTPS" ] ) ? "http://" : "https://") . $_SERVER[ "HTTP_HOST" ] . $_SERVER[ "REQUEST_URI" ];

			//パラメータを追加
			$H_auth[ 'item' ][ 'name' ]		= $item_name;
			$H_auth[ 'item' ][ 'cmd' ]		= 'ver_check';
			$H_auth[ 'item' ][ 'type' ]		= 'pl';
			$H_auth[ 'item' ][ 'ref_url' ]	= $ref_url;

			//REQUESTは削除しておく
			unset( $H_auth[ 'item' ][ 'REQUEST' ] );

			//配列からクエリーをビルドする
			$query_string					= http_build_query( $H_auth[ 'item' ] , null , '&' );

			//バージョンをチェックする
			$JP->VERSION_CHECK( 'https://wp-plugin.info/?' . $query_string , __FILE__ );
		}
	}
	//ダッシュボードにお知らせを表示する///////////////////////////////////////
	function USER_DASHBOARD_NOTICE()
	{
		global $JP;

		//プラグインのファイル名だけを取得
		$item_name		= pathinfo( __FILE__ , PATHINFO_FILENAME );

		//保存するオプション名
		$option_name	= $item_name . '-' . 'authentication';

		//オプション取得する
		$H_auth			= $JP->GET_OPTION( $option_name );

		//プラグインベース名
		$basename		= plugin_basename( __FILE__ );


		//値がないかエラーであれば
		if(! $H_auth or $H_auth[ 'res' ][ 'status' ] == 'error' )
		{
			//認証メニューまでのURL
			$auth_url = admin_url( 'admin.php?page=' . $basename );

echo <<< EOM
		<div id="message" class="error notice is-dismissible">
			<p>プラグイン {$item_name} の認証が完了していません。こちらから<a href="{$auth_url}">プラグインの認証</a>を行って下さい。</p>
			<button type="button" class="notice-dismiss">
				<span class="screen-reader-text">この通知を非表示にする</span>
			</button>
		</div>
EOM;

		}
	}
	//Ajax認証処理/////////////////////////////////////////////////////////////
	function AJAX_AUTHENTICATION()
	{
		global $JP;

		$token				= $_REQUEST[ 'token' ];
		$name1				= $_REQUEST[ 'name1' ];
		$name2				= $_REQUEST[ 'name2' ];
		$mail				= $_REQUEST[ 'mail' ];

		//送信先URL
//		$url				= 'http://localhost/wordpress/';
		$url				= 'https://wp-plugin.info/';

		//タイプ
		$type				= 'pl';	//プラグインタイプ

		//プラグインのファイル名だけを取得
		$item_name			= pathinfo( __FILE__ , PATHINFO_FILENAME );
		$nounce_key			= $item_name;

		//現在のURL
		$ref_url			= ( empty( $_SERVER[ "HTTPS" ] ) ? "http://" : "https://") . $_SERVER[ "HTTP_HOST" ] . $_SERVER[ "REQUEST_URI" ];


		//nonce が POST され正しい情報でなければ
		if(! wp_verify_nonce( $token , $nounce_key ) )
		{
			//終了
			$this->DMPF( "$token , $nounce_key\n" , "nonce_error.txt" , 1 );
			exit;
		}


		//jsonでヘッダー出力
		header( "Content-Type: application/json" );

		//管理者権限がなければ
		if(! current_user_can( 'manage_options' ) )
		{
			//エラー
			$response = json_encode( array( 'status' => 'error' , 'msg' => '管理者権限がありませんでした!' ) );
			echo $response;
			exit;
		}


		//メールアドレスの形式が間違いであれば
		if(! is_email( $mail ) )
		{
			//エラー
			$response = json_encode( array( 'status' => 'error' , 'msg' => 'メールアドレスが正しい形式ではありませんでした!' ) );
			echo $response;
			exit;
		}


		//送信するクエリパラメータ
		$H_arg				= array
		(
			'type'			=> $type ,
			'item_name'		=> $item_name ,
			'ref_url'		=> $ref_url ,
			'name1'			=> $name1 ,
			'name2'			=> $name2 ,
			'mail'			=> $mail ,
			'date'			=> date_i18n( 'U' ) ,
			'REQUEST'		=> $_REQUEST ,
		);

		//配列をラッピングする
		$H_param			= array
		(
			'cmd'			=> 'update-press_authentication' ,
			'item'			=> $H_arg ,
			'type'			=> $type ,
			'date'			=> date_i18n( 'U' ) ,
		);


		//リモートサイトの情報を取得する
		list( $code , $response ) = $JP->GET_REMOTE_SITE( $url , 5 , '' , 'POST' , $H_param );

		//本文を取得する
		$body				= wp_remote_retrieve_body( $response );

		//jsonデコードする
		$H_res				= json_decode( $body , true );

		//通信結果をセットする
		$H_param[ 'res' ]	= $H_res;


		//保存するオプション名
		$option_name		= $item_name . '-' . 'authentication';

		//OPTIONに保存する
		$JP->UPDATE_OPTION( $option_name , $H_param );


		//レスポンス用配列を返す
		$response			= json_encode( $H_res );

		echo $response;
		exit;

	}
	//アップデート認証/////////////////////////////////////////////////////////
	function UPDATE()
	{
		global $JP;

		//管理画面のチェック
		if(! $JP->ADMIN_WARNING() ) { return; }

		//プラグインのファイル名だけを取得
		$item_name	= pathinfo( __FILE__ , PATHINFO_FILENAME );
		$nounce_key	= $item_name;

		global $JP;

		//保存されたオプション名
		$option_name	= $item_name . '-' . 'authentication';

		//オプション取得する
		$H_auth			= $JP->GET_OPTION( $option_name );

		//コモンプリントアウトクラスを作成
		$Common_PrintOut = new mhs_Common_PrintOut();

		//コンテンツを出力する
		$Common_PrintOut->GET_CONTENT( $tran_key = 'mhs-common_content' , $index = 'Semantic UI' );
		$Common_PrintOut->GET_CONTENT( $tran_key = 'mhs-common_content' , $index = 'Dashboard Style' );

?>

<style>
	body{ background: #f1f1f1 !important; }
	.message.error{ display: none; }
	body, html
	{
		height: auto !important;
	}
</style>

<!-- 入力エラーモーダルダイアログ -->
<div class="ui modal input-error">
  <i class="close icon"></i>

  <div class="header">入力エラー</div>

  <div class="content">

    <div class="description">

      <div class="ui header">入力ミスがあります</div>

      <p>名前またはメールアドレスが正しく入力されていませんでした。再度確認した上で入力をお願いします。</p>
    </div>

  </div>

  <div class="actions">
    <div class="ui primary approve button">はい</div>

  </div>

</div>

<!-- ajax通信結果モーダルダイアログ -->
<div class="ui modal ajax-result">
  <i class="close icon"></i>

  <div class="header">認証結果</div>

  <div class="content">

    <div class="description">
      <p></p>
    </div>

  </div>

  <div class="actions">
    <div class="ui primary approve button">はい</div>

  </div>

</div>


<script type="text/javascript">

jQuery( function( $ )
{

	$( '#button' ).click( function()
	{
		//モーダルを初期化
		$( '.ui.modal.ajax-result .content p' ).empty();


		var $mail	= $( '#mail' ).val();
		var $name1	= $( '#name1' ).val();
		var $name2	= $( '#name2' ).val();

		//メールアドレスの形式でなければ
		if(! $mail.match( /^[-a-z0-9~!$%^&*_=+}{?]+(\.[-a-z0-9~!$%^&*_=+}{?]+)*@([a-z0-9_][-a-z0-9_]*(\.[-a-z0-9_]+)*\.(aero|arpa|biz|com|coop|edu|gov|info|int|mil|museum|name|net|org|pro|travel|mobi|[a-z][a-z])|([0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}))(:[0-9]{1,5})?$/i ) )
		{
			//モーダルダイアログを表示
			$( '.ui.modal.input-error' ).modal( 'show' );

			return false;
		}

		//メールまたは名前が入力されていなければ
		if(! $mail || ! $name1 || ! $name2 )
		{
			//モーダルダイアログを表示
			$( '.ui.modal.input-error' ).modal( 'show' );

			return false;
		}


		data = 
		{
			action 	: '<?php echo $item_name; ?>-user_authentication' ,	//アクションフックに紐付けする名前
			mail	: $mail ,
			name1	: $name1 ,
			name2	: $name2 ,
			token	: <?php echo '"' . wp_create_nonce( $nounce_key ) . '"'; ?> 
		};


		$.ajax(
		{
			url		: "<?php echo admin_url( 'admin-ajax.php' ); ?>" ,
			type	: 'POST' ,
			cache	: false ,
			data	: data
		})
		.success( function( data , state )
		{
			//書き換え
			$( '.ui.modal.ajax-result .content p' ).html( data.msg );

			//モーダルダイアログを表示
			$( '.ui.modal.ajax-result' ).modal( 'show' );

			console.log( state );
			console.log( data );
		})
		.error( function( XHR , state , error )
		{
			//書き換え
			$( '.ui.modal.ajax-result .content p' ).html( "通信処理は失敗しました" );

			//モーダルダイアログを表示
			$( '.ui.modal.ajax-result' ).modal( 'show' );

			console.log( XHR );
			console.log( state );
			console.log( error );
		});

	});

});
</script>


<div class="wrap">
	<h2>プラグインの認証</h2>

	<div class="ui form" style="margin-top: 2rem;">
		<h4 class="ui dividing header">全ての項目を正しく入力して下さい</h4>

		<div class="two fields">
			<div class="field">
			<label>苗字</label>
				<input id="name1" placeholder="苗字" type="text">
			</div>
		</div>

		<div class="two fields">
			<div class="field">
			<label>名前</label>
				<input id="name2" placeholder="名前" type="text">
			</div>
		</div>

		<div class="two fields">
			<div class="field">
			<label>メールアドレス</label>
				<input id="mail" placeholder="メールアドレス" type="text">
			</div>
		</div>

		<button id="button" class="ui primary button">認証</button>

	</div>

</div>

<?php
	}
	//アクションフックのコールバック関数///////////////////////////////////////
	function ADMIN_MENU()
	{
		//プラグインのファイル名だけを取得
		$plugin_name = pathinfo( __FILE__ , PATHINFO_FILENAME );

		$this->ADD_MENU( $plugin_name , 8 , __FILE__ , $this , 'UPDATE' , 'dashicons-cloud' );

//		$H_head	= get_file_data( __FILE__ , array( 'Name' => 'Plugin Name' ) );

		//サイドメニューを追加する
//		$this->ADD_MENU( $H_head[ 'Name' ] , 8 , __FILE__ , $this , 'UPDATE' , 'dashicons-cloud' );
	}
	//サイドメニュー追加する///////////////////////////////////////////////////
	function ADD_MENU( $menu_prefix , $level , $pid , $class_name , $do_func , $icon )
	{
		//サイドメニューに表示させる
		add_menu_page
		(
			$menu_prefix . ' - 設定' ,		//クリックした時に表示されるHTMLタイトル名
			$menu_prefix ,					//サイドメニューに表示させる名前(日本語OK)
			$level ,						//ユーザーレベル 10までありレベル8が一般的な管理レベル
			$pid ,							//プラグインの一意な識別子 __FILE__でファイル名を使うのが楽
			array( &$class_name , $do_func ),		//クリックしたら実行される関数
			$icon 							//表示するアイコン名
		);
	}
	//サイドメニュー追加する///////////////////////////////////////////////////
	function ADD_SUBMENU( $menu_prefix , $menu_title , $level , $pid , $class_name , $do_func  )
	{
		//サブメニューを追加する(メニューが複数ある場合)
		add_submenu_page
		(
			__FILE__,						//親メニューの名前 __FILE__ を使うと楽
			$menu_prefix ." - $menu_title",	//クリックした時に表示されるHTMLタイトル名
			$menu_title ,					//サブメニューで表示させる名前
			$level ,						//ユーザーレベル 10までありレベル8が一般的な管理レベル
			$pid ,							//プラグインの一意な識別子 関数名を書くと楽
			array( &$class_name , $do_func )//クリックしたら実行される関数
		);
	}
	//デバッグバックトレース///////////////////////////////////////////////////
	function DBT( $mode = 0 )
	{

		if( $mode )
		{
			echo "<pre>";
			print_r( debug_backtrace() );
			echo "</pre>";
		}
		else
		{
			//ログインユーザーのみに表示
			if( is_user_logged_in() )
			{
				echo "<pre>";
				print_r(  debug_backtrace() );
				echo "</pre>";
			}
		}

	}
	//データをファイルにダンプ/////////////////////////////////////////////////
	function DMPF( $data , $file_name = "test.txt" , $mode = 0 , $max_byte = 1048576 )
	{
		//出力のバッファリングを有効にする
		ob_start();
			var_dump( $data );
			$result = ob_get_contents();
		ob_end_clean();

		//追記モード
		if( $mode )
		{
			$fp = fopen( dirname(__FILE__) . "/$file_name" , "a" );
			$result .= "\n";
		}
		//上書きモード
		else
		{
			$fp = fopen( dirname(__FILE__) . "/$file_name" , "w" );
		}

		//デフォルトで最大1Mまで保存
		fwrite( $fp , $result , $max_byte );
		fclose( $fp );
	}
	//var_dumpを整形して表示する///////////////////////////////////////////////////
	function DMP( $value ,  $option = NULL )
	{

		//オプションがあればユーザー関係なく垂れ流し
		if( $option  == 1 )
		{
			echo "<pre>";
			var_dump( $value );
			echo "</pre>";
		}
		else if( $option  == 2 )
		{
			//ログインユーザーのみに表示
			if( is_user_logged_in() )
			{
				echo "<pre>";
				var_dump( $value );
				echo "</pre>";
			}
		}
		//デフォルト
		else
		{
			//ログインユーザーのみに表示
			if( is_user_logged_in() )
			{
				echo "<pre>";
				var_dump( $value );
				echo "</pre>";
			}
		}

	}
}
